==> dj-foundation-pro-1.0.100006.tgz: package/foundation/category/category+Object.js <==

Object.extend = function(destination, source) {
  for (let property in source) {
    destination[property] = source[property];
  }
  return destination;
}
Object.extend(Object, {








  /**
   * 类型判断
   * **/
  dj_typeOf(object) {
    const toString = Object.prototype.toString;
    const map = {
      '[object Boolean]'  : 'boolean',
      '[object Number]'   : 'number',
      '[object String]'   : 'string',
      '[object Function]' : 'function',
      '[object Array]'    : 'array',
      '[object Date]'     : 'date',
      '[object RegExp]'   : 'regExp',
      '[object Undefined]': 'undefined',
      '[object Null]'     : 'null',
      '[object Object]'   : 'object'
    };
    return map[toString.call(object)];
  },

  /**
   * 判断
   * 私有 不做备注 谨慎使用
   * **/
  dj_judge(object){
    if (typeof object == 'boolean'){
      if (object == false){
        return false;
      }
    }
  },

  /**
   * 深 copy
   * **/
  dj_copy(object){
    if (typeof object === 'string' || typeof object === 'number' || typeof object === 'boolean' || typeof object === 'undefined') {
      return object
    } else if (typeof object === 'array') {
      const mapper = [];
      for(let i=0;i<object.length;i++){
        mapper.push(Object.dj_copy(object[i]))
      }
      return mapper
    } else if (typeof object === 'object') {
      let mapper = new object.constructor ();
      for (let key in object) {
        if (object.hasOwnProperty(key)) {
          let val = object[key];
          mapper[key] = typeof val === 'object' ? arguments.callee(val) : val;
        }
      }
      return mapper;
    }
  },
  /**
   * 对象深度合并
   * **/
  dj_objectMerge(target,source){
    let key
    for (key in source) {
      target[key] = target[key] && target[key].toString() === '[object Object]'
        ? Object.dj_objectMerge(target[key], source[key])
        : (target[key] = source[key])
    }
    return target
  }
});

==> dj-foundation-pro-1.0.1000016.tgz: package/foundation/category/category+Object.js <==

Object.extend = function(destination, source) {
  for (let property in source) {
    destination[property] = source[property];
  }
  return destination;
}
Object.extend(Object, {








  /**
   * 类型判断
   * **/
  dj_typeOf(object) {
    const toString = Object.prototype.toString;
    const map = {
      '[object Boolean]'  : 'boolean',
      '[object Number]'   : 'number',
      '[object String]'   : 'string',
      '[object Function]' : 'common',
      '[object Array]'    : 'array',
      '[object Date]'     : 'date',
      '[object RegExp]'   : 'regExp',
      '[object Undefined]': 'undefined',
      '[object Null]'     : 'null',
      '[object Object]'   : 'object'
    };
    return map[toString.call(object)];
  },

  /**
   * 判断
   * 私有 不做备注 谨慎使用
   * **/
  dj_judge(object){
    if (typeof object == 'boolean'){
      if (object == false){
        return false;
      }
    }
  },

  /**
   * 深 copy
   * **/
  dj_copy(object){
    if (typeof object === 'string' || typeof object === 'number' || typeof object === 'boolean' || typeof object === 'undefined') {
      return object
    } else {
      let copy = object instanceof Array ? [] : {}
      for (let i in object) {
        if (object.hasOwnProperty(i)) {
          copy[i] = typeof object[i] === 'object' ? this.dj_copy(object[i]) : object[i]
        }
      }
      return copy
    }
    // else if (typeof object === 'array') {
    //   const mapper = [];
    //   for(let i=0;i<object.length;i++){
    //     mapper.push(Object.dj_copy(object[i]))
    //   }
    //   return mapper
    // } else if (typeof object === 'object') {
    //   let mapper = new object.constructor ();
    //   for (let key in object) {
    //     if (object.hasOwnProperty(key)) {
    //       let val = object[key];
    //       mapper[key] = typeof val === 'object' ? arguments.callee(val) : val;
    //     }
    //   }
    //   return mapper;
    // }
  },
  /**
   * 对象深度合并
   * **/
  dj_objectMerge(target,source){
    let key
    for (key in source) {
      target[key] = target[key] && target[key].toString() === '[object Object]'
        ? Object.dj_objectMerge(target[key], source[key])
        : (target[key] = source[key])
    }
    return target
  }
});
